@@ -20,7 +20,7 @@
 #if (__GNUC__ == 3 && __GNUC_MINOR__ < 4)
 #include <bits/stl_alloc.h>
 #else
-extern "C" char* getenv(char const* name);	// Needed before including ext/pool_allocator.h.
+#include <cstdlib>		// Needed for getenv, needed by ext/pool_allocator.h.
 #include <ext/pool_allocator.h>
 #endif
 #undef private
@@ -206,7 +206,12 @@ void allocator_unlock(void)
       }
     };
 
-    void buffer_ct::writeto(std::ostream* os LIBCWD_COMMA_TSD_PARAM, debug_ct& debug_object,
+    void buffer_ct::writeto(std::ostream* os LIBCWD_COMMA_TSD_PARAM,
+#if LIBCWD_THREAD_SAFE
+        debug_ct& debug_object,
+#else
+        debug_ct&,
+#endif
 	bool request_unfinished, bool do_flush COMMA_IFTHREADS(bool ends_on_newline)
 	COMMA_IFTHREADS(bool possible_nonewline_cf))
     {
@@ -820,7 +825,7 @@ void allocator_unlock(void)
       if (!_private_::WST_is_NPTL && pthread_self() == (pthread_t)2049)
       {
 	::write(1, "WARNING: Thread manager core dumped.  Going into infinite loop.  Please detach process with gdb.\n", 97);
-	while(1);
+	while(1) ;
       }
 #endif
       raise(6);
@@ -1150,7 +1155,7 @@ void allocator_unlock(void)
       set_alloc_checking_on(LIBCWD_TSD);
     }
 
-    void debug_tsd_st::finish(debug_ct& debug_object, channel_set_data_st& channel_set LIBCWD_COMMA_TSD_PARAM)
+    void debug_tsd_st::finish(debug_ct& debug_object, channel_set_data_st& /*UNUSED, */ LIBCWD_COMMA_TSD_PARAM)
     {
 #if CWDEBUG_DEBUG
       LIBCWD_ASSERT( current != reinterpret_cast<laf_ct*>(_private_::WST_dummy_laf) );
@@ -1285,7 +1290,7 @@ void allocator_unlock(void)
 	  if (debug_object.interactive)
 	  {
 	    *target_os << std::flush;
-	    while(std::cin.get() != '\n');
+	    while(std::cin.get() != '\n') ;
 	  }
 #if LIBCWD_THREAD_SAFE
 	  debug_object.M_mutex->unlock();
@@ -1461,7 +1466,11 @@ void allocator_unlock(void)
 
 #if LIBCWD_THREAD_SAFE
     namespace _private_ {
+#if CWDEBUG_DEBUGT
+      void debug_tsd_init(LIBCWD_TSD_PARAM_UNUSED)
+#else
       void debug_tsd_init(LIBCWD_TSD_PARAM)
+#endif
       {
 	ForAllDebugObjects(
 	  set_alloc_checking_off(LIBCWD_TSD);
@@ -1617,6 +1626,8 @@ void allocator_unlock(void)
       DEBUG_CHANNELS_ACQUIRE_WRITE_LOCK;
 
       set_alloc_checking_off(LIBCWD_TSD);	// debug_channels is internal.
+      const_cast<char*>(channels::dc::core.get_label())[WST_max_len] = ' ';
+      const_cast<char*>(channels::dc::fatal.get_label())[WST_max_len] = ' ';
       _private_::debug_channels_ct::container_type& channels(_private_::debug_channels.write_locked());
       for(_private_::debug_channels_ct::container_type::iterator i(channels.begin()); i != channels.end(); ++i)
 	const_cast<char*>((*i)->get_label())[WST_max_len] = ' ';
@@ -1639,6 +1650,8 @@ void allocator_unlock(void)
       if (label_len > WST_max_len)
 	WST_max_len = label_len;
 
+      const_cast<char*>(channels::dc::core.get_label())[WST_max_len] = '\0';
+      const_cast<char*>(channels::dc::fatal.get_label())[WST_max_len] = '\0';
       for(_private_::debug_channels_ct::container_type::iterator i(channels.begin()); i != channels.end(); ++i)
 	const_cast<char*>((*i)->get_label())[WST_max_len] = '\0';
       for(_private_::debug_channels_ct::container_type::iterator i(channels_not_listed.begin());
@@ -1856,28 +1869,6 @@ void allocator_unlock(void)
       return *reinterpret_cast<continued_channel_set_st*>(this);
     }
 
-    channel_set_st& channel_set_bootstrap_st::operator|(fatal_channel_ct const&)
-    {
-#if CWDEBUG_LOCATION
-      DoutFatal(dc::fatal, location_ct((char*)__builtin_return_address(0) + libcwd::builtin_return_address_offset) <<
-          " : Don't use Dout together with dc::core or dc::fatal!  Use DoutFatal instead.");
-#else
-      DoutFatal(dc::core,
-          "Don't use Dout together with dc::core or dc::fatal!  Use DoutFatal instead.");
-#endif
-    }
-
-    channel_set_st& channel_set_bootstrap_st::operator&(channel_ct const&)
-    {
-#if CWDEBUG_LOCATION
-      DoutFatal(dc::fatal, location_ct((char*)__builtin_return_address(0) + libcwd::builtin_return_address_offset) <<
-	  " : Use dc::core or dc::fatal together with DoutFatal.");
-#else
-      DoutFatal(dc::core,
-	  "Use dc::core or dc::fatal together with DoutFatal.");
-#endif
-    }
-
     namespace _private_ {
 
       void assert_fail(char const* expr, char const* file, int line, char const* function)
